OMERO.dropbox
=============

Introduction
------------

OMERO.dropbox provides a server for watching directories
for new files which are then imported into OMERO.

Dependencies
------------

Direct dependencies of OMERO.dropbox are:

- `ZeroC IcePy`_
- `OMERO.py`_

Installation
------------

See: `OMERO`_ documentation

Usage
-----

See: `OMERO`_ documentation

Contributing
------------

See: `OMERO`_ documentation

Running tests
-------------

Unit tests are located under the `test` directory and can be run with pytest.

Integration tests
^^^^^^^^^^^^^^^^^

Integration tests are stored in the main repository (ome/openmicroscopy) and depend on the
OMERO integration testing framework. Reading about `Running and writing tests`_ in the `OMERO`_ documentation
is essential.

License
-------

OMERO.dropbox is released under the GPL v2.

Copyright
---------

2009-2020, The Open Microscopy Environment, Glencoe Software, Inc.

.. _OMERO: https://www.openmicroscopy.org/omero
.. _OMERO.py: https://pypi.python.org/pypi/omero-py
.. _ZeroC IcePy: https://zeroc.com/
.. _Running and writing tests: https://docs.openmicroscopy.org/latest/omero/developers/testing.html
